==> EspoCRM-5.8.2.zip: EspoCRM-5.8.2/client/modules/crm/src/controllers/unsubscribe.js <==
/************************************************************************
 * This file is part of EspoCRM.
 *
 * EspoCRM - Open Source CRM application.
 * Copyright (C) 2014-2020 Yuri Kuznetsov, Taras Machyshyn, Oleksiy Avramenko
 * Website: https://www.espocrm.com
 *
 * EspoCRM is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * EspoCRM is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with EspoCRM. If not, see http://www.gnu.org/licenses/.
 *
 * The interactive user interfaces in modified source and object code versions
 * of this program must display Appropriate Legal Notices, as required under
 * Section 5 of the GNU General Public License version 3.
 *
 * In accordance with Section 7(b) of the GNU General Public License version 3,
 * these Appropriate Legal Notices must retain the display of the "EspoCRM" word.
 ************************************************************************/

Espo.define('crm:controllers/unsubscribe', 'controller', function (Dep) {

    return Dep.extend({

        actionUnsubscribe: function (data) {
            var viewName = data.view || 'crm:views/campaign/unsubscribe';

            var template = this.getMetadata().get(['clientDefs', 'Campaign', 'unsubscribeTemplate']);

            this.entire(viewName, {
                actionData: data.actionData,
                template: data.template,
            }, function (view) {
                view.render();
            });
        },

        actionSubscribeAgain: function (data) {
            var viewName = data.view || 'crm:views/campaign/subscribe-again';

            var template = this.getMetadata().get(['clientDefs', 'Campaign', 'subscribeTemplate']);

            this.entire(viewName, {
                actionData: data.actionData,
                template: data.template,
            }, function (view) {
                view.render();
            });
        }

    });
});

==> EspoCRM-8.0.5.zip: EspoCRM-8.0.5/client/modules/crm/src/controllers/unsubscribe.js <==
/************************************************************************
 * This file is part of EspoCRM.
 *
 * EspoCRM - Open Source CRM application.
 * Copyright (C) 2014-2023 Yurii Kuznietsov, Taras Machyshyn, Oleksii Avramenko
 * Website: https://www.espocrm.com
 *
 * EspoCRM is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * EspoCRM is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with EspoCRM. If not, see http://www.gnu.org/licenses/.
 *
 * The interactive user interfaces in modified source and object code versions
 * of this program must display Appropriate Legal Notices, as required under
 * Section 5 of the GNU General Public License version 3.
 *
 * In accordance with Section 7(b) of the GNU General Public License version 3,
 * these Appropriate Legal Notices must retain the display of the "EspoCRM" word.
 ************************************************************************/

import Controller from 'controller';

class UnsubscribeController extends Controller {

    // noinspection JSUnusedGlobalSymbols
    actionUnsubscribe(data) {
        const viewName = data.view || 'crm:views/campaign/unsubscribe';

        this.entire(viewName, {
            actionData: data.actionData,
            template: data.template,
        }, view => {
            view.render();
        });
    }

    // noinspection JSUnusedGlobalSymbols
    actionSubscribeAgain(data) {
        const viewName = data.view || 'crm:views/campaign/subscribe-again';

        this.entire(viewName, {
            actionData: data.actionData,
            template: data.template,
        }, view => {
            view.render();
        });
    }
}

export default UnsubscribeController;
